@@ -21,10 +21,12 @@ import subprocess
 import platform
 
 import click
+import requests
 import yaml
+from git import Repo
 
 from pcm import util, requirements, render
-from pcm.util import find_prog, handle_check_call
+from pcm.util import find_prog, handle_check_call, r_mkdir
 
 IS_MAC = platform.system() == "Darwin"
 IS_WINDOWS = platform.system() == "Windows"
@@ -56,6 +58,45 @@ def _login(env, app_id):
     util.write(environment_file, yaml.dump(t))
 
 
+def _conda(environment, app, verbose):
+    click.secho("conda install", bold=True, fg="green")
+    req = requirements.CONDA_REQUIREMENTS
+    pip_req = requirements.PIP_REQUIREMENTS
+
+    if app == "pyvalve":
+        req.extend(requirements.VALVE_REQUIREMENTS)
+    else:
+        pip_req.extend(requirements.PIP_EXTRAS)
+
+    cmdargs = ["edm", "install", "-y"] + req
+    active_python = os.path.join(HOME, ".edm")
+    if environment:
+        active_python = os.path.join(
+            active_python, "envs", environment, "bin", "python"
+        )
+        cmdargs.extend(["--environment", environment])
+
+        handle_check_call(["edm", "environments", "create", environment])
+    else:
+        active_python = os.path.join(active_python, "bin", "python")
+
+    if verbose:
+        click.echo(f'requirements: {" ".join(req)}')
+        click.echo(f'command: {" ".join(cmdargs)}')
+
+    handle_check_call(cmdargs)
+    handle_check_call(
+        [
+            active_python,
+            "-m",
+            "pip",
+            "install",
+            "--no-dependencies",
+        ]
+        + pip_req
+    )
+
+
 def _edm(environment, app, verbose):
     click.secho("edm install", bold=True, fg="green")
     req = requirements.EDM_REQUIREMENTS
@@ -213,6 +254,8 @@ def _launcher(
         "edm_envs_root": EDM_ENVS_ROOT,
         "edm_env": environment,
         "pychron_path": os.path.join(HOME, f".pychron.{app_id}", "pychron"),
+        "update_db": 0,
+        "alembic_url": "",
     }
 
     txt = render.render_template(template, **ctx)
@@ -322,46 +365,55 @@ def _spectrometer_init(kind, env, overwrite):
 
 def _metarepo(name, env, overwrite):
     root = os.path.join(HOME, env, "data", ".dvc", name)
-    os.mkdir(root)
+    r_mkdir(root)
+    if not os.path.isfile(os.path.join(root, ".git")):
+        repo = Repo.init(root)
+    else:
+        repo = Repo(root)
 
     ih = os.path.join(root, "irradiation_holders")
-    os.mkdir(ih)
+    r_mkdir(ih)
     template = "Grid.txt"
-    txt = render.render_template(template)
     p = os.path.join(ih, template)
-    util.write(p, txt, overwrite)
-
-    ni = os.path.join(root, "NoIrradiation")
-    os.mkdir(ni)
-
-    template = "productions.json"
-    p = os.path.join(ni, template)
     txt = render.render_template(template)
-    util.write(p, txt, overwrite)
+    util.write(p, txt, overwrite=overwrite)
+    repo.index.add(p)
 
-    pp = os.path.join(ni, "productions")
-    os.mkdir(pp)
+    noi = os.path.join(root, "NoIrradiation")
+    r_mkdir(noi)
 
     template = "A.json"
-    p = os.path.join(ni, template)
+    p = os.path.join(noi, template)
     txt = render.render_template(template)
-    util.write(p, txt, overwrite)
+    util.write(p, txt, overwrite=overwrite)
 
+    prod = os.path.join(noi, "productions")
+    r_mkdir(prod)
     template = "NoIrradiation.json"
+    p = os.path.join(prod, template)
     txt = render.render_template(template)
-    nipp = os.path.join(pp, template)
-    util.write(nipp, txt, overwrite)
+    util.write(p, txt, overwrite=overwrite)
 
-    cp = os.path.join(ni, "chronology.txt")
-    with open(cp, "w") as wfile:
-        pass
+    p = os.path.join(noi, "productions.json")
+    txt = '{"A"; "NoIrradiation"}'
+    util.write(p, txt, overwrite=overwrite)
 
-    # init as a git repo
-    git = find_prog("git")
-    if not git:
-        click.secho("Could not locate git executable", fg="red")
-        return
-    subprocess.call([git, "init"], cwd=root)
+    p = os.path.join(noi, "chronology.txt")
+    txt = ""
+    util.write(p, txt, overwrite=overwrite)
+
+
+def _fetch(name, env):
+    output = os.path.join(HOME, env)
+    base = "https://raw.githubusercontent.com/PychronLabsLLC/pychronpackages/main"
+    url = f"{base}/{name}"
+    resp = requests.get(url)
+    print(resp)
+    if resp.status_code == 200:
+        name = os.path.basename(name)
+        path = os.path.join(output, name)
+        with open(path, "w") as wfile:
+            wfile.write(resp.text)
 
 
 # ============= EOF =============================================
